==> haskell-edisoncore-1.3.2.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonCore
version: 1.3.2.1
id: EdisonCore-1.3.2.1-HDqflZmcs4p7h7mrL2jjDf
key: EdisonCore-1.3.2.1-HDqflZmcs4p7h7mrL2jjDf
license: MIT
maintainer: robdockins AT fastmail DOT fm
author: Chris Okasaki
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (Core Implementations)
description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.
category: Data Structures
abi: c8ba108ac93ad4089e6167082ca6238e
exposed: True
exposed-modules:
    Data.Edison.Assoc.AssocList Data.Edison.Assoc.Defaults
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Coll.Defaults
    Data.Edison.Coll.EnumSet Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.UnbalancedSet
    Data.Edison.Concrete.FingerTree Data.Edison.Seq.BankersQueue
    Data.Edison.Seq.BinaryRandList Data.Edison.Seq.BraunSeq
    Data.Edison.Seq.Defaults Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq
import-dirs: /usr/lib/ghc-8.6.5/site-local/EdisonCore-1.3.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/EdisonCore-1.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/EdisonCore-1.3.2.1
hs-libraries: HSEdisonCore-1.3.2.1-HDqflZmcs4p7h7mrL2jjDf
depends:
    EdisonAPI-1.3.1-IEeVeuMM4NbBkXuVWfeYgY
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA array-0.5.3.0
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2
haddock-interfaces: /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html: /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisoncore-1.3.2.1-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonCore
version: 1.3.2.1
id: EdisonCore-1.3.2.1-BaF4b6jp1OrGwxLqsRsutt
key: EdisonCore-1.3.2.1-BaF4b6jp1OrGwxLqsRsutt
license: MIT
maintainer: robdockins AT fastmail DOT fm
author: Chris Okasaki
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficient, purely-functional data structures (Core Implementations)
description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.
category: Data Structures
abi: 176b9baaa61a7a7c6d33c0f819737e9f
exposed: True
exposed-modules:
    Data.Edison.Assoc.AssocList Data.Edison.Assoc.Defaults
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Coll.Defaults
    Data.Edison.Coll.EnumSet Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.UnbalancedSet
    Data.Edison.Concrete.FingerTree Data.Edison.Seq.BankersQueue
    Data.Edison.Seq.BinaryRandList Data.Edison.Seq.BraunSeq
    Data.Edison.Seq.Defaults Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq
import-dirs: /usr/lib/ghc-8.6.5/site-local/EdisonCore-1.3.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/EdisonCore-1.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/EdisonCore-1.3.2.1
hs-libraries: HSEdisonCore-1.3.2.1-BaF4b6jp1OrGwxLqsRsutt
depends:
    EdisonAPI-1.3.1-IEeVeuMM4NbBkXuVWfeYgY
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW array-0.5.3.0
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2
haddock-interfaces: /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html: /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
